﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.DataPresenter.Events;
using Infragistics.Windows.Editors;

using XamDataGridSelection.ViewModels;

namespace XamDataGridSelection
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            MainWindowViewModel _mainWindowViewModel = new MainWindowViewModel();
            ChannelXamDataGrid.DataContext = _mainWindowViewModel;
            ChannelXamDataGrid.DataSource = ((MainWindowViewModel)ChannelXamDataGrid.DataContext).ChannelViewModels;
            ChannelXamDataGrid.EditModeEnded += new EventHandler<Infragistics.Windows.DataPresenter.Events.EditModeEndedEventArgs>(xamDataGrid1_EditModeEnded);

            EventManager.RegisterClassHandler(typeof(XamCheckEditor), XamCheckEditor.ValueChangedEvent, new RoutedPropertyChangedEventHandler<object>(xamDataGridCheckChanged));
        }

        void xamDataGridCheckChanged(object sender, RoutedPropertyChangedEventArgs<object> e)
        {
            if (sender is XamCheckEditor)
            {
                ((XamCheckEditor)sender).EndEditMode(true, true);
            }
        }

        void xamDataGrid1_EditModeEnded(object sender, Infragistics.Windows.DataPresenter.Events.EditModeEndedEventArgs e)
        {
            Debug.WriteLine("Edit Mode Ended");
        }

        void OnLeftMouseButtonDown(object sender, MouseEventArgs e)
        {
            var xx = sender as XamCheckEditor;
            if (xx != null)
            {
                xx.StartEditMode();
                xx.IsChecked = !xx.IsChecked;
                xx.EndEditMode(true, true);
            }
        }
        private IEnumerable<ChannelViewModel>  _channels;
        /// <summary>
        /// Handles the Sorting event of the XamDataGrid control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="Infragistics.Windows.DataPresenter.Events.SortingEventArgs"/> instance containing the event data.</param>
        private void OnXamDataGridSorting(object sender, SortingEventArgs e)
        {
            if (_channels == null)
            {
                _channels = ChannelXamDataGrid.DataSource as IEnumerable<ChannelViewModel>;
            }

            ListSortDirection sortDirection = e.SortDescription.Direction;

            switch (sortDirection)
            {
                case ListSortDirection.Ascending:
                    SortAsc(e.SortDescription.FieldName);
                    break;
                case ListSortDirection.Descending:
                    SortDesc(e.SortDescription.FieldName);
                    break;
            }
        }

        /// <summary>
        /// Sorts the channel as asc.
        /// </summary>
        /// <param name="fieldName">Name of the field.</param>
        private void SortAsc(string fieldName)
        {            
            switch (fieldName)
            {
                case "Name":
                    ChannelXamDataGrid.DataSource = _channels.OrderBy(c => c.Name);
                    return;
                case "SelectedChannelType":
                    ChannelXamDataGrid.DataSource = _channels.OrderBy(c => c.SelectedChannelType);
                    return;
                case "Description":
                    ChannelXamDataGrid.DataSource = _channels.OrderBy(c => c.Description);
                    return;                
            }            
        }

        /// <summary>
        /// Sorts the channels as desc.
        /// </summary>
        /// <param name="fieldName">Name of the field.</param>
        private void SortDesc(string fieldName)
        {
            switch (fieldName)
            {
                case "Name":
                    ChannelXamDataGrid.DataSource = _channels.OrderByDescending(c => c.Name);
                    return;
                case "SelectedChannelType":
                    ChannelXamDataGrid.DataSource = _channels.OrderByDescending(c => c.SelectedChannelType);
                    return;
                case "Description":
                    ChannelXamDataGrid.DataSource = _channels.OrderByDescending(c => c.Description);
                    return;
               
            }
            
        }

        void cValueChanged(object sender, RoutedPropertyChangedEventArgs<object> e)
        {
            XamCheckEditor editor = sender as XamCheckEditor;
            editor.EndEditMode(true, true);
        }
    }
}
